Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(65)

Unified Diff: device/bluetooth/bluetooth_remote_gatt_characteristic_bluez.cc

Issue 1542163002: Switch to standard integer types in device/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: win Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/bluetooth_remote_gatt_characteristic_bluez.cc
diff --git a/device/bluetooth/bluetooth_remote_gatt_characteristic_bluez.cc b/device/bluetooth/bluetooth_remote_gatt_characteristic_bluez.cc
index 75c6f1ae27c4fc8847a10779476fe2b0cc1b63fb..e76c57e48841455ecfa27b3e63377b0ad3dca707 100644
--- a/device/bluetooth/bluetooth_remote_gatt_characteristic_bluez.cc
+++ b/device/bluetooth/bluetooth_remote_gatt_characteristic_bluez.cc
@@ -21,10 +21,10 @@ namespace bluez {
namespace {
-// Stream operator for logging vector<uint8>.
-std::ostream& operator<<(std::ostream& out, const std::vector<uint8> bytes) {
+// Stream operator for logging vector<uint8_t>.
+std::ostream& operator<<(std::ostream& out, const std::vector<uint8_t> bytes) {
out << "[";
- for (std::vector<uint8>::const_iterator iter = bytes.begin();
+ for (std::vector<uint8_t>::const_iterator iter = bytes.begin();
iter != bytes.end(); ++iter) {
out << base::StringPrintf("%02X", *iter);
}
@@ -94,7 +94,7 @@ bool BluetoothRemoteGattCharacteristicBlueZ::IsLocal() const {
return false;
}
-const std::vector<uint8>& BluetoothRemoteGattCharacteristicBlueZ::GetValue()
+const std::vector<uint8_t>& BluetoothRemoteGattCharacteristicBlueZ::GetValue()
const {
bluez::BluetoothGattCharacteristicClient::Properties* properties =
bluez::BluezDBusManager::Get()
@@ -191,7 +191,7 @@ bool BluetoothRemoteGattCharacteristicBlueZ::AddDescriptor(
}
bool BluetoothRemoteGattCharacteristicBlueZ::UpdateValue(
- const std::vector<uint8>& value) {
+ const std::vector<uint8_t>& value) {
VLOG(1) << "Cannot update the value of a remote GATT characteristic.";
return false;
}
@@ -211,7 +211,7 @@ void BluetoothRemoteGattCharacteristicBlueZ::ReadRemoteCharacteristic(
}
void BluetoothRemoteGattCharacteristicBlueZ::WriteRemoteCharacteristic(
- const std::vector<uint8>& new_value,
+ const std::vector<uint8_t>& new_value,
const base::Closure& callback,
const ErrorCallback& error_callback) {
VLOG(1) << "Sending GATT characteristic write request to characteristic: "

Powered by Google App Engine
This is Rietveld 408576698